from descriptors import IntDescriptor, StringDescriptor
from luko_rada_package_1.rada_factories import (
    UkraineRadaFactory,
    PolandRadaFactory
)


class MetaDescriptors(type):
    def __new__(cls, clsname, bases, dct):
        new_dict = {}
        for name, value in dct.items():
            if name == 'int_types':
                for x in value:
                    new_dict[x] = IntDescriptor()
            elif name == 'str_types':
                for x in value:
                    new_dict[x] = StringDescriptor()
            else:
                new_dict[name] = value
        return type.__new__(cls, clsname, bases, new_dict)



from rada_factories import UkraineRadaFactory, PolandRadaFactory

simulation_config_file = {'rada': 'Poland'}


if __name__=="__main__":
    if simulation_config_file['rada'] == 'Ukraine':
        UkraineRadaFactory()().run()
    else:
        PolandRadaFactory()().run()



from luko_rada_package_1.rada_factories import (
    UkraineRadaFactory,
    PolandRadaFactory
)
# Functor sorts deputies by params
class Sorting:

    def __init__(self, *args):
        self.args = args

    def __call__(self, instance):
        values = []
        for value in self.args:
            values.append(getattr(instance, value))
        return values
